##  Enable API Service Integration in Okta
To integrate Okta, you need to enable SAP LeanIX API service integration in the Okta admin panel.
To do so, follow these steps:
  1. Open Okta admin panel and go to Applications > API Service Integrations and click Add Integration
![Enabling API Sevice Integration](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27538b0c7a441014ac9fe8be6bfd565a_LowRes.png)
Enabling API Sevice Integration
  2. Select LeanIX - SaaS Discovery application and click Next. Note that it requires okta.app.read scope.
  3. Okta automatically selects and presents the required permission. You can review them and click on Install & Authorize.
![Authorizing LeanIX - SaaS Discovery](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2745adea7a4410148e1bd56c6408dd2c_LowRes.png)
Authorizing LeanIX - SaaS Discovery
  4. Copy the Client Secret and click Done.
![Copy Client Secret](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2742fc697a44101483a2ca6cb2f1dc17_LowRes.png)
Copy Client Secret
  5. Copy Okta Domain and Client ID.
![Copy Okta Domain and Client ID](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2747b8017a4410149bc8b55fff3a958a_LowRes.png)
Copy Okta Domain and Client ID
